@@ -117,7 +117,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
             data.update(allow_online_registration=plugins.users.allow_online_registration)
 
         if settings.SITE.is_installed('notify'):
-            data.update(use_push_api=plugins.notify.use_push_api)
+            data.update(use_push_api=plugins.notify.use_push_api and settings.SITE.use_linod)
 
         # data.update(actors={str(a): a for a in self.actors_list})
         # data.update(action_param_panels={
@@ -199,9 +199,12 @@ class Renderer(JsRenderer, JsCacheRenderer):
         # Slave tables
         if hasattr(v, "actor"):
             # reference to actor data for slave-grids
-            result.update(obj2dict(v.actor, "actor_id"))  # to get siteDate layout index
+            result.update(obj2dict(v.actor, "actor_id display_mode"))  # to get siteDate layout index
             # if str(v.actor) == "system.Dashboard":
             #     print("20210617c", v.value, result)
+            if hasattr(v, 'slaves') and v.slaves is not None:
+                for k, v in v.slaves.items():
+                    result[k] = self.elem2json(v)
 
         # if hasattr(v, "get_field_options"):
         if issubclass(v.__class__, FieldElement):
@@ -555,6 +558,18 @@ class Renderer(JsRenderer, JsCacheRenderer):
 
         return result, hotkeys
 
+    def display_mode2json(self, display_mode):
+        dms = []  # display modes
+        dmd = None  # display mode default
+        for item in display_mode:
+            if item[0] is None:
+                dmd = item[1]
+            else:
+                dms.append(list(item))
+        dms = sorted(dms, key=lambda x: x[0])
+        dms.append([None, dmd])
+        return dms
+
     def actor2json(self, v):
         assert isclass(v) and issubclass(v, Actor)
         al , hk = self.actions2json(v._actions_list)
@@ -601,7 +616,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                   "hide_navigator "
                                   "use_detail_params_value "
                                   "react_responsive "
-                                  "display_mode_main "
+                                  # "display_mode "
                                   "max_render_depth "
                                   "simple_slavegrid_header "
                                   "paginator_template "
@@ -612,6 +627,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
         if hasattr(v.model, "file"):
             result.update(contain_media=True)
 
+        if v.display_mode is not None:
+            result['display_mode'] = self.display_mode2json(v.display_mode)
+
         if v.detail_action is not None:
             wl = v.detail_action.get_window_layout()
             if wl is not None:
@@ -624,10 +642,10 @@ class Renderer(JsRenderer, JsCacheRenderer):
         if card_layout is not None:
             result.update(card_layout=card_layout._formpanel_name)
 
-        item_layout = getattr(v, "item_layout", None)
-        if item_layout is not None:
-            # print("20210629", v, "item_layout is", item_layout)
-            result.update(item_layout=item_layout._formpanel_name)
+        list_layout = getattr(v, "list_layout", None)
+        if list_layout is not None:
+            # print("20210629", v, "list_layout is", list_layout)
+            result.update(list_layout=list_layout._formpanel_name)
         # mt + slave-tables
 
         chooser_dict = getattr(v.model, "_choosers_dict", {})
